@@ -1,7 +1,7 @@
 /* Requester handling.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2005 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2006 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
@@ -28,7 +28,7 @@
 
 /* This is the expected max length of the current directory name. */
 
-#define CUR_DIR_MAX_SIZE		4096
+#define CUR_DIR_MAX_SIZE		(16*1024)
 
 /* These are the default allocation sizes for the entry array and for the
 name array when reading a directory. The allocation sizes start with these
@@ -460,20 +460,7 @@ char *request_files(const char * const filename, int use_prefix) {
 					}
 
 					if (num_entries) {
-
-#ifdef _AMIGA
-						if (num_entries - 1) qsort(entries + 1, num_entries - 1, sizeof(char *), strcmpp);
-#else
-						if (num_entries - 2 >= 0) {
-							if (!strcmp(entries[0], "./") && !strcmp(entries[1], "../")) {
-								p = entries[0];
-								entries[0] = entries[1];
-								entries[1] = p;
-							}
-							if (num_entries - 2 > 0 )
-								qsort(entries + 2, num_entries - 2, sizeof(char *), strcmpp);
-						}
-#endif
+						qsort(entries, num_entries, sizeof(char *), filenamecmpp);
 
 						if ((i = request_strings((const char * const *)entries, num_entries, max_name_len)) != ERROR) {
 							p = entries[i >= 0 ? i : -i - 2];
