@@ -1,7 +1,7 @@
 /* Miscellaneous support functions.
 
 	Copyright (C) 1993-1998 Sebastiano Vigna 
-	Copyright (C) 1999-2005 Todd M. Lewis and Sebastiano Vigna
+	Copyright (C) 1999-2006 Todd M. Lewis and Sebastiano Vigna
 
 	This file is part of ne, the nice editor.
 
@@ -270,6 +270,19 @@ int strcmpp(const void *a, const void *b) {
 }
 
 
+/* A filename comparison function for qsort(). It makes "../" the first string, "./" the second string
+   and then orders lexicographically. */
+
+int filenamecmpp(const void *a, const void *b) {
+	const char *s = *(const char **)a, *t = *(const char **)b; 
+	if (strcmp(s, "../")==0) return strcmp(t, "../") == 0 ? 0 : -1;
+	if (strcmp(t, "../")==0) return 1;
+	if (strcmp(s, "./")==0) return strcmp(t, "./") == 0 ? 0 : -1;
+	if (strcmp(t, "./")==0) return 1;
+	return strcmp(s, t);
+}
+
+
 
 #ifdef _AMIGA
 
