@@ -386,9 +386,9 @@ void set_terminal_modes(void) {
 	and the file which should be used, if present, to initialize the
 	terminal. */
 
-	OUTPUT1_IF(ne_init_1string);
+	/*OUTPUT1_IF(ne_init_1string);
 	OUTPUT1_IF(ne_init_2string);
-	OUTPUT1_IF(ne_init_3string);
+	OUTPUT1_IF(ne_init_3string);*/
 
 	OUTPUT1_IF(ne_exit_attribute_mode);
 	OUTPUT1_IF(ne_exit_alt_charset_mode);
